diff --git a/dumux/porousmediumflow/2p2c/implicit/volumevariables.hh b/dumux/porousmediumflow/2p2c/implicit/volumevariables.hh
index ed3f2df9e458c394e2dfa0b170706ff2896a064a..1a0756ea3b344b43a0d48579bfd34306be72010a 100644
--- a/dumux/porousmediumflow/2p2c/implicit/volumevariables.hh
+++ b/dumux/porousmediumflow/2p2c/implicit/volumevariables.hh
@@ -258,14 +258,14 @@ public:
         // now comes the tricky part: calculate phase compositions
         if (phasePresence == bothPhases) {
             // both phases are present, phase compositions are a
-            // result of the the nonwetting <-> wetting equilibrium. This is
+            // result of the nonwetting <-> wetting equilibrium. This is
             // the job of the "MiscibleMultiPhaseComposition"
             // constraint solver
             if(useConstraintSolver) {
                 MiscibleMultiPhaseComposition::solve(fluidState,
                                                      paramCache,
                                                      /*setViscosity=*/true,
-                                                     /*setInternalEnergy=*/false);
+                                                     /*setEnthalpy=*/false);
             }
             // ... or calculated explicitly this way ...
             else {
@@ -330,7 +330,7 @@ public:
                                                  paramCache,
                                                  nPhaseIdx,
                                                  /*setViscosity=*/true,
-                                                 /*setInternalEnergy=*/false);
+                                                 /*setEnthalpy=*/false);
             }
             // ... or calculated explicitly this way ...
             else {
@@ -395,7 +395,7 @@ public:
                                                  paramCache,
                                                  wPhaseIdx,
                                                  /*setViscosity=*/true,
-                                                 /*setInternalEnergy=*/false);
+                                                 /*setEnthalpy=*/false);
             }
             // ... or calculated explicitly this way ...
             else {
diff --git a/dumux/porousmediumflow/2pnc/implicit/volumevariables.hh b/dumux/porousmediumflow/2pnc/implicit/volumevariables.hh
index e3d0940813ee845e782989d44b3e362194d44457..723123a8d424ec76bc37dbf9e4b0b6cf8980fe96 100644
--- a/dumux/porousmediumflow/2pnc/implicit/volumevariables.hh
+++ b/dumux/porousmediumflow/2pnc/implicit/volumevariables.hh
@@ -269,7 +269,7 @@ public:
                         paramCache,
                         wPhaseIdx,  //known phaseIdx
                         /*setViscosity=*/true,
-                        /*setInternalEnergy=*/false);
+                        /*setEnthalpy=*/false);
         }
         else if (phasePresence == nPhaseOnly){
 
@@ -302,7 +302,7 @@ public:
                                                 paramCache,
                                                 nPhaseIdx,
                                                 /*setViscosity=*/true,
-                                                /*setInternalEnergy=*/false);
+                                                /*setEnthalpy=*/false);
 
             }
         else if (phasePresence == wPhaseOnly){
@@ -338,7 +338,7 @@ public:
                                                 paramCache,
                                                 wPhaseIdx,
                                                 /*setViscosity=*/true,
-                                                /*setInternalEnergy=*/false);
+                                                /*setEnthalpy=*/false);
         }
         paramCache.updateAll(fluidState);
         for (int phaseIdx = 0; phaseIdx < numPhases; ++phaseIdx)
diff --git a/dumux/porousmediumflow/2pncmin/implicit/volumevariables.hh b/dumux/porousmediumflow/2pncmin/implicit/volumevariables.hh
index f5b3930f3f544c8746dff7ccd17ece33261efcea..e775435e054bbf4d34b6b088d151d734cde7a686 100644
--- a/dumux/porousmediumflow/2pncmin/implicit/volumevariables.hh
+++ b/dumux/porousmediumflow/2pncmin/implicit/volumevariables.hh
@@ -290,7 +290,7 @@ public:
                                             paramCache,
                                             wPhaseIdx,  //known phaseIdx
                                             /*setViscosity=*/true,
-                                            /*setInternalEnergy=*/false);
+                                            /*  =*/false);
         }
         else if (phasePresence == nPhaseOnly)
         {
@@ -336,7 +336,7 @@ public:
                                                     nPhaseIdx,
                                                     nPhaseOnly,
                                                     /*setViscosity=*/true,
-                                                    /*setInternalEnergy=*/false);
+                                                    /*setEnthalpy=*/false);
 
             }
         else if (phasePresence == wPhaseOnly)
@@ -374,7 +374,7 @@ public:
                                                     wPhaseIdx,
                                                     wPhaseOnly,
                                                     /*setViscosity=*/true,
-                                                    /*setInternalEnergy=*/false);
+                                                    /*setEnthalpy=*/false);
         }
         paramCache.updateAll(fluidState);
         for (int phaseIdx = 0; phaseIdx < numPhases; ++phaseIdx)
diff --git a/dumux/porousmediumflow/3p3c/implicit/volumevariables.hh b/dumux/porousmediumflow/3p3c/implicit/volumevariables.hh
index a7b8aceb34f855782c76a4ac3027a152a2da7970..388ea943c232bd08e47612b51b62f9fc362ee6ef 100644
--- a/dumux/porousmediumflow/3p3c/implicit/volumevariables.hh
+++ b/dumux/porousmediumflow/3p3c/implicit/volumevariables.hh
@@ -217,7 +217,7 @@ public:
                 MiscibleMultiPhaseComposition::solve(fluidState_,
                                                      paramCache,
                                                      /*setViscosity=*/true,
-                                                     /*setInternalEnergy=*/false);
+                                                     /*setEnthalpy=*/false);
             }
             // ... or calculated explicitly this way ...
             // please note that we experienced some problems with un-regularized
@@ -295,7 +295,7 @@ public:
                                                  paramCache,
                                                  wPhaseIdx,
                                                  /*setViscosity=*/true,
-                                                 /*setInternalEnergy=*/false);
+                                                 /*setEnthalpy=*/false);
             }
             // ... or calculated explicitly this way ...
             else {
@@ -364,7 +364,7 @@ public:
                                              paramCache,
                                              gPhaseIdx,
                                              /*setViscosity=*/true,
-                                             /*setInternalEnergy=*/false);
+                                             /*setEnthalpy=*/false);
         }
         else if (phasePresence == wnPhaseOnly) {
             // only water and NAPL phases are present
@@ -388,7 +388,7 @@ public:
                                              paramCache,
                                              wPhaseIdx,
                                              /*setViscosity=*/true,
-                                             /*setInternalEnergy=*/false);
+                                             /*setEnthalpy=*/false);
         }
         else if (phasePresence == gPhaseOnly) {
             // only the gas phase is present, gas phase composition is
@@ -412,7 +412,7 @@ public:
                                                  paramCache,
                                                  gPhaseIdx,
                                                  /*setViscosity=*/true,
-                                                 /*setInternalEnergy=*/false);
+                                                 /*setEnthalpy=*/false);
             }
             // ... or calculated explicitly this way ...
             else {
@@ -474,7 +474,7 @@ public:
                                                  paramCache,
                                                  gPhaseIdx,
                                                  /*setViscosity=*/true,
-                                                 /*setInternalEnergy=*/false);
+                                                 /*setEnthalpy=*/false);
             }
             // ... or calculated explicitly this way ...
             else {
diff --git a/dumux/material/constraintsolvers/fluidsystemconstraintsolver.hh b/dumux/material/constraintsolvers/fluidsystemconstraintsolver.hh
index 52dce277ad8fe91a498780b810daecbea922946a..c0666795364a3541691e686d7ed402a621365cc3 100644
--- a/dumux/material/constraintsolvers/fluidsystemconstraintsolver.hh
+++ b/dumux/material/constraintsolvers/fluidsystemconstraintsolver.hh
@@ -55,7 +55,7 @@ namespace Dumux {
  * - composition in mole and mass fractions and molarities of *all* phases
  * - mean molar masses of *all* phases
  * - if the setViscosity parameter is true, also dynamic viscosities of *all* phases
  * - if the setInternalEnergy parameter is true, also specific enthalpies and internal energies of *all* phases
  */
 template <class Scalar, class FluidSystem>
 class FluidSystemConstraintSolver
@@ -119,13 +119,13 @@ public:
      * \param fluidState A container with the current (physical) state of the fluid
      * \param paramCache A container for iterative calculation of fluid composition
      * \param setViscosity Should the viscosity be set in the fluidstate?
      * \param setInternalEnergy Should the enthalpy be set in the fluidstate?
      */
     template <class FluidState, class ParameterCache>
     static void solve(FluidState & fluidState,
                       ParameterCache & paramCache,
                       const bool setViscosity,
-                      const bool setInternalEnergy)
+                      const bool setEnthalpy)
     {
 
         // In this function the actual work is done.
@@ -143,7 +143,7 @@ public:
                 fluidState.setViscosity(phaseIdx, value);
             }
 
-            if (setInternalEnergy) {
+            if (setEnthalpy) {
                 value = FluidSystem::enthalpy(fluidState, paramCache, phaseIdx);
                 fluidState.setEnthalpy(phaseIdx, value);
             }
@@ -55,7 +55,7 @@ namespace Dumux {
  * - mean molar masses of *all* phases
  * - if the setViscosity parameter is true, also dynamic viscosities of *all* phases
- * - if the setInternalEnergy parameter is true, also specific enthalpies and internal energies of *all* phases
+ * - if the setEnthalpy parameter is true, also specific enthalpies of *all* phases
  */
 template <class Scalar, class FluidSystem>
@@ -119,13 +119,13 @@ public:
      * \param paramCache A container for iterative calculation of fluid composition
      * \param setViscosity Should the viscosity be set in the fluidstate?
-     * \param setInternalEnergy Should the enthalpy be set in the fluidstate?
+     * \param setEnthalpy Should the enthalpy be set in the fluidstate?
      */
     template <class FluidState, class ParameterCache>
diff --git a/dumux/material/constraintsolvers/miscible2pnccomposition.hh b/dumux/material/constraintsolvers/miscible2pnccomposition.hh
index fb561f7e042eeb5508a607e56c0190a675dde842..9f26f1e7d12b3099b12160c5d68c0edfe470e0ac 100644
--- a/dumux/material/constraintsolvers/miscible2pnccomposition.hh
+++ b/dumux/material/constraintsolvers/miscible2pnccomposition.hh
@@ -55,7 +55,7 @@ namespace Dumux {
  * - mean molar masses of *all* phases
  * - fugacity coefficients of *all* components in *all* phases
  * - if the setViscosity parameter is true, also dynamic viscosities of *all* phases
  * - if the setInternalEnergy parameter is true, also specific enthalpies and internal energies of *all* phases
  */
 template <class Scalar, class FluidSystem>
 class Miscible2pNCComposition
@@ -94,7 +94,7 @@ public:
                       ParameterCache &paramCache,
                       const int knownPhaseIdx,
                       bool setViscosity,
-                      bool setInternalEnergy)
+                      bool setEnthalpy)
     {
 #ifndef NDEBUG
         // currently this solver can only handle fluid systems which
@@ -216,7 +216,7 @@ public:
                 fluidState.setViscosity(phaseIdx, value);
             }
 
-            if (setInternalEnergy) {
+            if (setEnthalpy) {
                 value = FluidSystem::enthalpy(fluidState, paramCache, phaseIdx);
                 fluidState.setEnthalpy(phaseIdx, value);
             }
@@ -55,7 +55,7 @@ namespace Dumux {
  * - fugacity coefficients of *all* components in *all* phases
  * - if the setViscosity parameter is true, also dynamic viscosities of *all* phases
- * - if the setInternalEnergy parameter is true, also specific enthalpies and internal energies of *all* phases
+ * - if the setEnthalpy parameter is true, also specific enthalpies of *all* phases
  */
 template <class Scalar, class FluidSystem>
diff --git a/dumux/material/constraintsolvers/misciblemultiphasecomposition.hh b/dumux/material/constraintsolvers/misciblemultiphasecomposition.hh
index a28c87caa71ab0d43395b39db4957289bfbe561e..217902df3970a112993eb3ed59d1188a12363d36 100644
--- a/dumux/material/constraintsolvers/misciblemultiphasecomposition.hh
+++ b/dumux/material/constraintsolvers/misciblemultiphasecomposition.hh
@@ -55,7 +55,7 @@ namespace Dumux {
  * - mean molar masses of *all* phases
  * - fugacity coefficients of *all* components in *all* phases
  * - if the setViscosity parameter is true, also dynamic viscosities of *all* phases
  * - if the setInternalEnergy parameter is true, also specific enthalpies and internal energies of *all* phases
  */
 template <class Scalar, class FluidSystem>
 class MiscibleMultiPhaseComposition
@@ -96,7 +96,7 @@ public:
     static void solve(FluidState &fluidState,
                       ParameterCache &paramCache,
                       bool setViscosity,
-                      bool setInternalEnergy)
+                      bool setEnthalpy)
     {
 #ifndef NDEBUG
         // currently this solver can only handle fluid systems which
@@ -194,7 +194,7 @@ public:
                 fluidState.setViscosity(phaseIdx, value);
             }
 
-            if (setInternalEnergy) {
+            if (setEnthalpy) {
                 value = FluidSystem::enthalpy(fluidState, paramCache, phaseIdx);
                 fluidState.setEnthalpy(phaseIdx, value);
             }
@@ -55,7 +55,7 @@ namespace Dumux {
  * - fugacity coefficients of *all* components in *all* phases
  * - if the setViscosity parameter is true, also dynamic viscosities of *all* phases
- * - if the setInternalEnergy parameter is true, also specific enthalpies and internal energies of *all* phases
+ * - if the setEnthalpy parameter is true, also specific enthalpies of *all* phases
  */
 template <class Scalar, class FluidSystem>